@@ -7,7 +7,7 @@ from aws_cdk import (
 
 ##
 ## CodeCommit
-def createCodeCommitRepository(self, repository_name, initial_commit=None):
+def createCodeCommitRepository(self, repository_name, initial_commit_dir=None, initial_commit_branch=None):
     """
     Creates a CodeCommit Repository.
  
@@ -15,10 +15,16 @@ def createCodeCommitRepository(self, repository_name, initial_commit=None):
     :param initial_commit: CodeCommit Repository Initial Commit (defaul=None)
     :return: CodeCommit Repository Object
     """ 
+    code = None
+    commit_branch = "main"
+    if initial_commit_branch is None:
+        commit_branch = initial_commit_branch
+    if initial_commit_dir is not None:
+        code = codecommit.Code.from_directory(initial_commit_dir, commit_branch)
     repo = codecommit.Repository(
         self, 'CDK-CodeCommit-Repository-{}'.format(repository_name),
         repository_name= repository_name,
-        code=initial_commit
+        code=code
     )
     return repo
 
