@@ -5,14 +5,22 @@ from aws_cdk import (
 from constructs import Construct 
 
 from OpenSSL import crypto
+import base64
+
 
 
 
 
 def get_apns_certificate(cert_path, cert_pw):
     p12 = crypto.load_pkcs12(open(cert_path, 'rb').read(), cert_pw)
-    pem = crypto.dump_privatekey(crypto.FILETYPE_PEM, p12.get_privatekey())
-    return pem.decode("utf-8")
+    pem = crypto.dump_certificate(crypto.FILETYPE_PEM, p12.get_certificate())
+    print(pem)
+    print(pem.decode("ascii"))
+    print(pem.decode("utf-8"))
+    message_bytes = pem.decode("utf-8").encode('ascii')
+    base64_bytes = base64.b64encode(message_bytes)
+    base64_message = base64_bytes.decode('ascii')
+    return base64_message
 
 
 class NotificationStack(Stack): 
@@ -31,10 +39,10 @@ class NotificationStack(Stack):
 
             # the properties below are optional
             bundle_id=apns_bundle_id,
-            # certificate=apns_certificate.get_certificate(),
-            default_authentication_method="key",
+            certificate=apns_certificate,
+            default_authentication_method="certificate",
             enabled=True,
-            private_key=apns_certificate,
+            # private_key=apns_certificate,
             # team_id="teamId",
             # token_key="tokenKey",
             # token_key_id="tokenKeyId"
